====================================
User Guide
====================================

.. _fig.gemviz_gui:

.. figure:: _static/gemviz_gui.png
    :alt: fig.gemviz_gui
    :width: 80%

Command-line
------------

todo

.. todo:
    Export
    ------

    * data
    * plot script (such as SVG)
    * plot image
